==> re-admin-0.17.1.tgz: package/es/containers/AdminContext/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _class, _class2, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { BrowserRouter, Route, Switch } from 'react-router-dom';
import { observable } from 'mobx';
import { observer } from 'mobx-react';
import routerStore from '../../stores/routerStore';
import authStore from '../../stores/authStore';
import AppConfigContext from '../../contexts/AppConfig';
import { Router } from 'react-router-mobx';
import DocumentTitle from 'react-document-title';

var styles = {
	container: {
		height: '100%'
	}
};

var AdminContext = observer(_class = (_temp = _class2 = function (_Component) {
	_inherits(AdminContext, _Component);

	_createClass(AdminContext, [{
		key: 'getChildContext',
		value: function getChildContext() {
			return {
				appConfig: this._appConfig,
				authStore: authStore
			};
		}
	}]);

	function AdminContext(props) {
		_classCallCheck(this, AdminContext);

		var _this = _possibleConstructorReturn(this, (AdminContext.__proto__ || Object.getPrototypeOf(AdminContext)).call(this, props));

		_this._appConfig = observable(props.appConfig);
		authStore.set(_this._appConfig);
		return _this;
	}

	_createClass(AdminContext, [{
		key: 'componentDidUpdate',
		value: function componentDidUpdate(_ref) {
			var appConfig = _ref.appConfig;

			Object.assign(this._appConfig, appConfig);
			authStore.set(this._appConfig);
		}
	}, {
		key: 'render',
		value: function render() {
			var _props$appConfig = this.props.appConfig,
			    title = _props$appConfig.title,
			    footer = _props$appConfig.footer,
			    _props$appConfig$navi = _props$appConfig.navigator,
			    Frame = _props$appConfig$navi.frame,
			    Login = _props$appConfig$navi.login,
			    basename = _props$appConfig$navi.basename,
			    otherNaviProps = _objectWithoutProperties(_props$appConfig$navi, ['frame', 'login', 'basename']);

			return React.createElement(
				AppConfigContext.Provider,
				{ value: this._appConfig },
				React.createElement(
					DocumentTitle,
					{ title: title },
					React.createElement(
						Router,
						{
							component: BrowserRouter,
							basename: basename,
							routerStore: routerStore
						},
						React.createElement(
							'div',
							{ style: styles.container },
							React.createElement(
								Switch,
								null,
								React.createElement(Route, { path: '/login', component: Login }),
								React.createElement(Route, {
									render: function render(_ref2) {
										var location = _ref2.location;
										return React.createElement(Frame, _extends({
											locKey: location.key,
											footer: footer
										}, otherNaviProps));
									}
								})
							)
						)
					)
				)
			);
		}
	}]);

	return AdminContext;
}(Component), _class2.propTypes = {
	appConfig: PropTypes.object
}, _class2.childContextTypes = {
	appConfig: PropTypes.object,
	authStore: PropTypes.object
}, _temp)) || _class;

export { AdminContext as default };

==> re-admin-0.19.0-0.tgz: package/es/containers/AdminContext/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _class, _class2, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { BrowserRouter, Route, Switch } from 'react-router-dom';
import { observable } from 'mobx';
import { observer } from 'mobx-react';
import routerStore from '../../stores/routerStore';
import authStore from '../../stores/authStore';
import AppConfigContext from '../../contexts/AppConfig';
import { Router } from 'react-router-mobx';
import DocumentTitle from 'react-document-title';

var styles = {
	container: {
		height: '100%'
	}
};

var AdminContext = observer(_class = (_temp = _class2 = function (_Component) {
	_inherits(AdminContext, _Component);

	_createClass(AdminContext, [{
		key: 'getChildContext',
		value: function getChildContext() {
			return {
				appConfig: this._appConfig,
				authStore: authStore
			};
		}
	}]);

	function AdminContext(props) {
		_classCallCheck(this, AdminContext);

		var _this = _possibleConstructorReturn(this, (AdminContext.__proto__ || Object.getPrototypeOf(AdminContext)).call(this, props));

		_this._appConfig = observable(props.appConfig);
		authStore.set(_this._appConfig);
		return _this;
	}

	_createClass(AdminContext, [{
		key: 'componentDidUpdate',
		value: function componentDidUpdate(_ref) {
			var appConfig = _ref.appConfig;

			Object.assign(this._appConfig, appConfig);
			authStore.set(this._appConfig);
		}
	}, {
		key: 'render',
		value: function render() {
			var _props$appConfig = this.props.appConfig,
			    title = _props$appConfig.title,
			    footer = _props$appConfig.footer,
			    _props$appConfig$navi = _props$appConfig.navigator,
			    Frame = _props$appConfig$navi.frame,
			    Login = _props$appConfig$navi.login,
			    SetPassword = _props$appConfig$navi.setPassword,
			    basename = _props$appConfig$navi.basename,
			    otherNaviProps = _objectWithoutProperties(_props$appConfig$navi, ['frame', 'login', 'setPassword', 'basename']);

			return React.createElement(
				AppConfigContext.Provider,
				{ value: this._appConfig },
				React.createElement(
					DocumentTitle,
					{ title: title },
					React.createElement(
						Router,
						{
							component: BrowserRouter,
							basename: basename,
							routerStore: routerStore
						},
						React.createElement(
							'div',
							{ style: styles.container },
							React.createElement(
								Switch,
								null,
								React.createElement(Route, { path: '/login', component: Login }),
								React.createElement(Route, { path: '/password', component: SetPassword }),
								React.createElement(Route, {
									render: function render(_ref2) {
										var location = _ref2.location;
										return React.createElement(Frame, _extends({
											locKey: location.key,
											footer: footer
										}, otherNaviProps));
									}
								})
							)
						)
					)
				)
			);
		}
	}]);

	return AdminContext;
}(Component), _class2.propTypes = {
	appConfig: PropTypes.object
}, _class2.childContextTypes = {
	appConfig: PropTypes.object,
	authStore: PropTypes.object
}, _temp)) || _class;

export { AdminContext as default };
